#
# spec file for package falkon
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
Name:           falkon
Version:        23.08.4
Release:        2.2
Summary:        Modern web browser
License:        GPL-3.0-or-later
URL:            https://www.falkon.org/
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
# Search engine favicons.
Source3:        obs.png
Source4:        opensusesoftware.png
# No QtWebEngine for other archs
ExclusiveArch:  %{arm} aarch64 %{ix86} x86_64 %{riscv}
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Purpose)
BuildRequires:  cmake(KF5Wallet)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5QuickWidgets)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5WebChannel)
BuildRequires:  cmake(Qt5WebEngineCore)
BuildRequires:  cmake(Qt5WebEngineWidgets)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(xcb-util)
# It fails to build for the moment
#BuildRequires:  cmake(PySide2)
#BuildRequires:  cmake(Shiboken2)
#BuildRequires:  python3-devel
# it doesn't start without it (boo#1067547)
Requires:       libQt5Sql5-sqlite
Recommends:     %{name}-kde
Provides:       qupzilla = %{version}
Provides:       web_browser
Obsoletes:      qupzilla < %{version}
Provides:       falkon-gnome-keyring = %{version}
Obsoletes:      falkon-gnome-keyring < %{version}

%description
Falkon is a web browser designed to well integrate with all
common Linux desktops like GNOME and KDE Plasma.
It supports current web standards and comes with many features,
such as an integrated ad blocker.

It was previously known as QupZilla.

%package kde
Summary:        Plugin for tighter integration of KDE technologies
Requires:       %{name} = %{version}
Supplements:    (%{name} and plasma5-workspace)
Supplements:    (%{name} and plasma6-workspace)
Provides:       falkon-kwallet = %{version}
Obsoletes:      falkon-kwallet < %{version}
Provides:       qupzilla-kwallet = %{version}
Obsoletes:      qupzilla-kwallet < %{version}

%description kde
Plugin for the Falkon browser that allows tighter integration of KDE technologies,
such as storing passwords in KWallet.

%lang_package

%prep
%autosetup -p1

# openSUSE icons.
cp -f %{SOURCE3} %{SOURCE4} src/lib/data/icons/sites/

%if %{with released}
# The plugins are not installed if PySide is not present at build time.
find po/ -name "falkon_helloqml.po" -o -name "falkon_hellopython.po" -exec rm {} \;
%endif

# Decrease the minimum CMake version for 15.3.
# There's no technical reason for requiring CMake 3.18.
sed -i 's/VERSION 3.18/VERSION 3.17/' CMakeLists.txt

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --all-name --with-qt

%suse_update_desktop_file org.kde.falkon
%fdupes %{buildroot}%{_kf5_sharedir}/

%ldconfig_scriptlets

%files
%license COPYING
%doc CHANGELOG README.md
%{_kf5_appstreamdir}/org.kde.falkon.appdata.xml
%{_kf5_bindir}/falkon
%{_kf5_libdir}/libFalkonPrivate.so.*
%{_kf5_plugindir}/falkon/
%{_kf5_sharedir}/applications/org.kde.falkon.desktop
%{_kf5_sharedir}/bash-completion/
%{_kf5_sharedir}/falkon/
%{_kf5_sharedir}/icons/hicolor/*/apps/falkon.*
%exclude %{_kf5_plugindir}/falkon/KDEFrameworksIntegration.so

%files kde
%{_kf5_plugindir}/falkon/KDEFrameworksIntegration.so

%files lang -f %{name}.lang

%changelog
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Change falkon-kde dependencies:
  * Supplement plasma[56]-workspace instead of kwallet
  * Remove hard dep on kwallet, it's optional and users probably use
    it the other way around, i.e. use falkon with already installed
    kwalletd.
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- Changes since 23.08.3:
  * Process the "--help-all" CLI argument (kde#477492)
  * Fix StartPage search engine default configuration (kde#419530)
  * Fix crash when starting new session after crash (kde#408701)
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * snapcraft: Rebuild with new content pack to fix mixed libraries. (kde#476503)
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * SessionRestore: Set tab title after at the end
  * Skip show/hide close button when restoring session (kde#455012)
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * Add support for custom url schemes (kde#434099)
  * Show page zoom level in locationbar (kde#399001)
  * Fix: Folder disappears when moving it onto itself (kde#462891)
  * Addressbar use default search engine by default (kde#405423)
  * History: Don't delete all items under dates when filtering (kde#466936)
  * KWallet: Store passwords entries in map fortmat (kde#391298)
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Preferences: Use default search engine by default
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Thu Mar 24 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Falkon is now released with other KDE Gear.
* Mon Jan 31 2022 Wolfgang Bauer <wbauer@tmo.at>
- Update to 3.2.0
  * Add support for Screen Capture (Qt 5.13.2+)
  * Option for internal PDFium-based viewer (Qt 5.13+)
  * CookieManager: Add support for selecting more than one cookie
    at once
  * Correct the sorting for cookies white- and black- lists
  * Speeddial: decode initialScript data as Utf8
  * Set current tab as parent for duplicated tab
  * add support for detaching tabs via context menu (kde#443947)
  * BookmarksManager: Don't allow to create bookmark without parent
  * Remove the padding of the bookmark bar
  * Added context menu item to bookmarks toolbar for creating
    folder
  * Preferences: Add links to KDE store for installing
    themes/extensions
  * OcsSupport: Add initial support for downloading
    themes/extensions
  * Add filter to preferences extensions page
  * SideBarManager: Clear active sidebar upon close
  * Added focus for searchbar in history sidebar & bookmark sidebar
  * SearchToolBar: Remove warning message that no results were
    found
  * SearchBar - Show number of matches found on page search
  * added pause/resume for downloads
  * Prompt user when KWallet is disabled
  * KDEFrameworksIntegration: Create Purpose menu in init
  * GreaseMonkey: Fix detecting *.user.js urls
  * Added QLoggingCategory to Falkon
  * Handle web push notifications with Falkon notification system
  * Fix name and set desktop entry for notifications
  * NetworkManager: Fix QtWebEngine warning about registering
    schemes
  * Don't use subfolders for QML/Python extensions
  * ThemeManager: Implement removing locally installed themes
  * Plugins: Implement removing locally installed plugins
  * Plugins: Use embedded JSON metadata for shared library plugins
  * RunAction plugin: set alternatingRowColors for listWidget
  * VerticalTabs: Accept click event on tree collapse
  * VerticalTabs: Draw unloaded tabs with "Disabled" color palette
  * VerticalTabs: Add child tab with middle click on "New Tab"
    button
  * VerticalTabs: Correctly recognize tree collapse / expand button
  * VerticalTabs: Also override Ctrl+PgUp/PgDown shortcuts
- Drop patches merged upstream:
  * Add-missing-include-in-last-qt5.14.patch
  * Fix-crash-when-KWallet-is-not-available.patch
  * 0001-Fix-build-with-Qt-5.15.patch
- Remove obsolete commands in %%post/%%postun
- Drop redundant recommendation of the -lang package
- Cleanup .spec file
- Add Source URL
- Add signature file and keyring
* Wed Jan 20 2021 Dirk Müller <dmueller@suse.com>
- switch to openssl build here - can't see how an inprocess mix
  of openssl (which qt is built against) and this would work
  otherwise
* Thu Jun  4 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch 0001-Fix-build-with-Qt-5.15.patch
* Sat Jan 25 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add Fix-crash-when-KWallet-is-not-available.patch to fix crashes
  with the KDE plugin if kwallet is disabled or cannot be opened
  for some reason (kde#398767)
* Fri Dec 27 2019 Wolfgang Bauer <wbauer@tmo.at>
- Add Add-missing-include-in-last-qt5.14.patch to fix build with Qt
  5.14
* Sun Mar 24 2019 Markus S <kamikazow@opensuse.org>
- Update to 3.1.0
  * add support for writing plugins in QML
  * add MiddleClickLoader Python plugin
  * add page sharing to KDE Frameworks Integration plugin
  * add basic support for client certificates (QtWebEngine >= 5.12)
  * add support for registering custom protocol handlers (QtWebEngine >= 5.12)
  * change search bar appearance to match other KDE apps
  * use DBus instead of lockfile/socket to check and communicate with other instances (Linux) #404494
  * whitelisted cookies are no longer deleted when deleting all cookies
  * Python plugin support is now stable
  * close entire tree after middle click on collapsed tabs in VerticalTabs plugin #399217
  * fix some compatibility issues with QtWebEngine up to 5.12
  * fix some possible crashes in AdBlock
  * fix builds with standalone QtWebEngine releases
* Sun Mar 10 2019 wbauer@tmo.at
- Provide web_browser (boo#1128005)
* Wed May  9 2018 Markus S <kamikazow@opensuse.org>
- Update 3.0.1
  * added profile migration from QupZilla
  * fix incorrectly completing form data on some sites #391327
  * fix showing incorrect state of back and forward buttons #391331
  * fix loading urls containing %%20 from location bar #392445
  * fix save page action for downloading text files #391300
  * fix download manager trying to closing not restored tabs #392565
  * fix updating location bar site icon after using paste and go action #392747
  * fix various issues with QtWebEngine 5.11 #392885, #393398
  * fix speed dial sometimes loading with no pages #391875
  * fix leaving html fullscreen after closing tab #393797
  * fix saving speed dial settings when there are no configured pages
  * fix restoring nested crashed sessions
  * fix setting minimum height of bookmarks toolbar
  * VerticalTabs: fix preserving expanded state of times inside collapsed parent #393567
  * VerticalTabs: don’t force open sidebar when opening new window #393629
- Remove falkon-defaults.patch because the speeddial and bookmarks bar handling
  has been completely rewritten and must be totally reworked (to do).
* Sat Apr 21 2018 Markus S <kamikazow@opensuse.org>
- Minor housekeeping
  * Change qupzilla.com URLs to falkon.org
  * Make the package description a bit more informative w/o using jargon
  * Clean up specfile from leftover stuff from older versions
* Tue Apr 10 2018 wbauer@tmo.at
- Require libQt5Sql5-sqlite, without it Falkon doesn't even start
  (boo#1067547)
* Sat Mar 10 2018 Markus S <kamikazow@opensuse.org>
- Minimum Qt version is 5.9 according to Falkon's CMakeLists.txt
* Tue Feb 27 2018 wbauer@tmo.at
- Version 3.0.0
  * released 27 February 2018
  * first Falkon release
  * added experimental support for Python extensions
* Tue Aug 29 2017 Markus S <kamikazow@opensuse.org>
- Small typo fix (Kwallet -> KWallet)
* Sat Aug 26 2017 fabian@ritter-vogt.de
- Initial packaging, copied from qupzilla package
